from django.core.management.base import NoArgsCommand

class Command(NoArgsCommand):
    help = "An example command to copy."

    def handle_noargs(self, **options):
        # Put execution code here.
        print("Example command")




import sys
import os
import argparse
import re
import subprocess
import shutil

TEMPLATE_PATH = os.path.join(os.path.dirname(os.path.realpath(__file__)), 'template')

def which(program):
    """
    Check path for an executable, or return None if not found.

    Taken from: http://stackoverflow.com/questions/377017/test-if-executable-exists-in-python
    """
    def is_exe(fpath):
        return os.path.isfile(fpath) and os.access(fpath, os.X_OK)

    fpath, fname = os.path.split(program)
    if fpath:
        if is_exe(program):
            return program
    else:
        for path in os.environ["PATH"].split(os.pathsep):
            path = path.strip('"')
            exe_file = os.path.join(path, program)
            if is_exe(exe_file):
                return exe_file

    return None


def file_replace(path, patterns):
    """
    Replace one or more patterns in a file.
    """

    content = open(path).read()

    # If only one pattern is given, change structure accordingly.
    if type(patterns[0]) == str:
        patterns = (patterns,)

    for pattern in patterns:
        content = content.replace(pattern[0], pattern[1])

    open(path, 'w').write(content)


class Cli(object):


    def run(self):
        parser = self.get_parser()
        args = parser.parse_args()

        if not self.check_requirements(args):
            sys.exit(1)

        if not self.check_args(args):
            sys.exit(1)

        print("Creating project " + args.name)
        self.create(args)


    def get_parser(self):
        parser = argparse.ArgumentParser(description='Kickstart a Django project.')
        parser.add_argument('--vcs', default='git', help="Set up a version control repository. Supported values: git|none")
        parser.add_argument('--virtualenv', help="Location for python virtualenv. If it already exists, the existing one will be used. Otherwise, a new one will be created.")
        parser.add_argument('--no-venv', action="store_true", help="Do not create a new virtual env, and not use an existing one. The system default will be used.")
        parser.add_argument('--no-db', action="store_true", help="Do not create a develoopment sqlite database.")
        parser.add_argument('--no-bower', action="store_true", help="Do not set up bower.")
        parser.add_argument('--verbose', '-v', action='store_true', help="More verbose output.")
        parser.add_argument('--domain', help="Domain that will be used in various parts of the setup.")
        parser.add_argument('--path', help="Parent directory for the new project. Defaults to current working dir.")
        parser.add_argument('--force', action="store_true", help="Delete old project if present.")
        parser.add_argument('name', help="Name of the new project.")

        return parser


    def check_args(self, args):
        name = re.sub(r'[^a-z0-9\_]', '', args.name).lower()
        if name != args.name:
            print("Invalid project name! Only use lower case letters, numbers or an underscore!")
            return False



        if args.path:
            path = os.path.realpath(args.path)
            if not os.path.exists(path):
                print("Given parent directory '{p}' does not exist, please create it first.".format(p=path))
                return False

        path = args.path if args.path else os.getcwd()
        path = os.path.join(path, name)

        if os.path.exists(path):
            if args.force:
                shutil.rmtree(path)
            else:
                print("Directory {d} already exists, delete it first or run with --force.".format(d=path))
                return False

        args.path = path

        return True

    def check_requirements(self, args):
        """
        Check the neccessary requirements for the installation.
        """

        print("Checking requirements...")

        # Check django-admin

        if not which('django-admin.py'):
            print("django-admin.py was not found on your path! Please ensure that Django is installed by running 'pip install Django'.")
            return False

        # Check virtualenv.
        if not args.no_venv:
            try:
                import virtualenv
            except:
                print("virtualenv was not found on your path! Please ensure that it is installed by running 'pip install virtualenv' OR disable virtualenv creation by specifying --no-venv.")
                return False
        else:
            # Check that pip is on the path.
            if not which('pip'):
                print("Pip was not found on your path! Install it first.")

        # Check vcs.
        vcs = args.vcs

        if vcs not in ('', 'none'):
            if vcs == 'git':
                # Check that git is on path.
                if not which('git'):
                    print("Git was not found on your path. Disable git repo creation with '--vcs=none'.")
                    return False
            else:
                print("Unsupported options for --vcs: '{v}'".format(v=vcs))
                return False

        # Check for bower.
        if not args.no_bower:
            if not which('bower'):
                print("bower was not found on your path! Ensure that bower is installed (npm install -g bower).")
                return False

        return True


    def create_project(self, name):
        code = subprocess.call([
            'django-admin.py',
            'startproject',
            '--template=' + TEMPLATE_PATH,
            '--extension=py,gitignore,txt,md,conf',
            name
        ])
        if code != 0:
            print("Error: django-admin.py failed")
            sys.exit(1)


    def create_virtualenv(self, path, settings_path):
        os.remove(os.path.join(path, '.gitkeep'))
        os.rmdir(path)

        import virtualenv

        virtualenv.create_environment(path,
            site_packages=True,
            unzip_setuptools=True,
        )


    def update_sitepackage_settings(self, virtualenv_path, settings_path, args):

        if not args.no_venv:
            # We need to update the VIRTENV_PACKAGE_DIR setting in settings.py
            # since it is needed for manage.py and wsgi.py.

            # Obviously skipped when no virtenv is created or used.

            # Determine virtualenv site packages location.
            site_packages_dir = subprocess.check_output([
                os.path.join(virtualenv_path, 'bin', 'python'),
                '-c',
                'from distutils.sysconfig import get_python_lib; print(get_python_lib())'
            ])
            site_packages_dir = site_packages_dir.replace("\n", "").replace(virtualenv_path + '/', "")

            # Now update the VIRTENV_PACKAGE_DIR setting.
            file_replace(settings_path, [('__VIRTENV_PACKAGE_DIR__', site_packages_dir)])


        if args.no_bower:
            # Remove essential bower setup from the settings.py since it's not used.
            file_replace(settings_path, [
                ("'djangobower.finders.BowerFinder',\n", ""),
                ("'djangobower',\n", ""),
            ])


    def install_python_requirements(self, pip, requirements_file):
        code = subprocess.call([pip, 'install', '-r', requirements_file])
        if code != 0:
            print("Error: Installing requirements with pip failed!")
            sys.exit(1)


    def create_db(self, manage_path, env):
        code = subprocess.call([manage_path, 'syncdb', '--migrate', '--noinput'], env=env)
        if code != 0:
            print("Error: could not run manage.py syncdb!")
            sys.exit(1)


    def fetch_bower_packages(self, manage_path, env):
        code = subprocess.call([manage_path, 'bower_install'], env=env)
        if code != 0:
            print("Error: Could not run manage.py bower_install")
            sys.exit(1)


    def create_vcs_git(self, path):
        os.chdir(path)
        code1 = subprocess.call(['git', 'init'])
        code2 = subprocess.call(['git', 'add', '-A'])
        code3 = subprocess.call(['git', 'commit', '-m', 'Initial commit by django-kickstart.'])

        if code1 != 0 or code2 != 0 or code3 != 0:
            print("Git repo creation failed!")
            sys.exit(1)


    def create(self, args):
        # Define all the paths.
        venv = args.virtualenv if args.virtualenv else os.path.join(args.path, 'pyenv')
        pip_bin = os.path.join(venv, 'bin', 'pip') if not args.no_venv else which("pip")
        app_path = os.path.join(args.path, 'app')
        django_manage = os.path.join(app_path, 'manage.py')
        settings_path = os.path.join(app_path, 'apps', args.name, 'settings.py')
        req_file = os.path.join(app_path, 'requirements', 'development.txt')

        # Prepare new env for manage.py commands.
        env = os.environ.copy()
        env['ENV'] = 'dev'

        # First, start new project with django-admin.
        print("Creating new project with django-admin.py...")
        self.create_project(args.name)

        # Create virtualenv.
        if not args.no_venv:
            if os.path.isdir(venv) and not os.path.isfile(os.path.join(venv, '.gitkeep')):
                print("Using virtual env " + venv)
            else:
                print("Creating new custom virtualenv...")
                self.create_virtualenv(venv, settings_path)

        self.update_sitepackage_settings(venv, settings_path, args)

        # Installing requirements.
        print('Installing python dependencies into virtualenv...')
        self.install_python_requirements(pip_bin, req_file)

        # Create developoment database, unless skipped by options.
        if not args.no_db:
            print("Creating development sqlite database and running south migrations...")
            self.create_db(django_manage, env)

        # Fetch bower packages.
        if not args.no_bower:
            print("Fetching bower packages...")
            self.fetch_bower_packages(django_manage, env)


        # Create vcs repository.
        if args.vcs == 'git':
            print("Creating GIT repository and making initial commit...")
            self.create_vcs_git(args.path)

        print("-" * 80)
        print("All done! Your new project is ready to use.")


def main():
    cli = Cli()
    cli.run()

if __name__ == "__main__" :
    main()



"""
Django settings for {{ project_name }}.

For more information on this file, see
https://docs.djangoproject.com/en/1.6/topics/settings/

For the full list of settings and their values, see
https://docs.djangoproject.com/en/1.6/ref/settings/


List of environment variables available:

ENV - the active environment

DEBUG - 1 or 0
TEMPLATE_DEBUG - 1 or 0

PUBLIC_DIR - the directory that holds publicly accessible files,
             expected subdirs are "media" and "static"
             if you want another setup, manually alter MEDIA_ROOT and STATIC_ROOT
VIRTENV_DIR - the root directory of the virtual env used

SECRET_KEY - the secret key
DB_ENGINE - the DB engine for the default DB
DB_NAME - the DB name for the default DB

ADMINS - the site admins, specify like this: ADMINS="admin1,admin 1@domain.com;admin 2,admin2@domain.com"
                          (seperate admins with ; and name from email with ,)

INTERNAL_IPS - separate by SPACE, like: INTERNAL_IPS="127.0.0.1 123.123.123.123"

EMAIL_BACKEND
EMAIL_HOST
EMAIL_PORT
EMAIL_HOST_USER
EMAIL_HOST_PASSWORD
EMAIL_USE_TLS

"""

import os

PROJECT_NAME = "{{ project_name }}"

# Build paths inside the project like this: os.path.join(BASE_DIR, ...)
ROOT_DIR = os.path.dirname(os.path.dirname(os.path.dirname(os.path.dirname(os.path.realpath(__file__)))))
# The virtual environment path. This is used in wsgi.py to put the virtual env
# on the PYTHONPATH automatically.
VIRTENV_DIR = os.environ.get('VIRTENV_DIR', os.path.join(ROOT_DIR, 'pyenv'))
# The path to the site packages used by the virtualenv.
# Note that this is relative to VIRTENV_DIR,
# so it might be "lib/python2.7/site-packages".
VIRTENV_PACKAGE_DIR = "__VIRTENV_PACKAGE_DIR__"

BASE_DIR = os.path.join(ROOT_DIR, 'app')
DATA_DIR = os.path.join(BASE_DIR, 'data')
PUBLIC_DIR = os.environ.get('PUBLIC_DIR', os.path.join(BASE_DIR, 'public'))

ENV = os.environ.get('ENV', 'production')

####################
# CORE             #
####################

DEBUG = bool(os.environ.get('DEBUG', True if ENV == 'dev' else False))
TEMPLATE_DEBUG = bool(os.environ.get('TEMPLATE_DEBUG', True if ENV == 'dev' else False))

# People who get code error notifications.
# In the format (('Full Name', 'email@example.com'), ('Full Name', 'anotheremail@example.com'))
# To specify with environment var, set it like this:
# ADMINS="admin1,admin1@domain.com;admin2,admin2@domain.com"
ADMINS = [l.split(',') for l in os.environ.get('ADMINS', '').split(';')]

# Tuple of IP addresses, as strings, that:
#   * See debug comments, when DEBUG is true
#   * Receive x-headers
INTERNAL_IPS = os.environ.get('INTERNAL_IPS', '127.0.0.1').split(' ')

# Hosts/domain names that are valid for this site.
# "*" matches anything, ".example.com" matches example.com and all subdomains
# For dev environment, this is set to all hosts.
ALLOWED_HOSTS = os.environ.get('ALLOWED_HOSTS', '').split(' ')

# Local time zone for this installation. All choices can be found here:
# http://en.wikipedia.org/wiki/List_of_tz_zones_by_name (although not all
# systems may support all possibilities). When USE_TZ is True, this is
# interpreted as the default user time zone.
TIME_ZONE = 'Europe/Vienna'

# If you set this to True, Django will use timezone-aware datetimes.
USE_TZ = True

# Language code for this installation. All choices can be found here:
# http://www.i18nguy.com/unicode/language-identifiers.html
LANGUAGE_CODE = 'de-DE'

# If you set this to False, Django will make some optimizations so as not
# to load the internationalization machinery.
USE_I18N = True

# If you set this to True, Django will format dates, numbers and calendars
# according to user current locale.
USE_L10N = False

# Not-necessarily-technical managers of the site. They get broken link
# notifications and other various emails.
MANAGERS = ADMINS

# Email address that error messages come from.
#SERVER_EMAIL = 'admin@DOMAIN.com'

# Database connection info. If left empty, will default to the dummy backend.
DATABASES = {}

# The email backend to use. For possible shortcuts see django.core.mail.
# The default is to use the SMTP backend.
# Third-party backends can be specified by providing a Python path
# to a module that defines an EmailBackend class.
EMAIL_BACKEND = os.environ.get('EMAIL_BACKEND', 'django.core.mail.backends.smtp.EmailBackend')

# Host for sending email.
EMAIL_HOST = os.environ.get('EMAIL_HOST', 'localhost')

# Port for sending email.
EMAIL_PORT = int(os.environ.get('EMAIL_PORT', 25))

# Optional SMTP authentication information for EMAIL_HOST.
EMAIL_HOST_USER = os.environ.get('EMAIL_HOST_USER', '')
EMAIL_HOST_PASSWORD = os.environ.get('EMAIL_HOST_PASSWORD', '')
EMAIL_USE_TLS = bool(os.environ.get('EMAIL_USE_TLS', False))

# List of strings representing installed apps.

INSTALLED_APPS = (

    # CUSTOM apps.

    '{{ project_name }}',

    # CONTRIB apps.

    # Asset manager
    'pipeline',

    # django-allauth
    'allauth',
    'allauth.account',
    'allauth.socialaccount',

    # django-allauth
    'allauth',
    'allauth.account',
    'allauth.socialaccount',

    # Schema migration.
    'south',

    # Helpful debug toolbar.
    'debug_toolbar',

    # Form helpers.
    'crispy_forms',

    # Django bower integration.
    # https://github.com/nvbn/django-bower
    'djangobower',

    # DJANGO CORE apps.
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',

    # Site framework, needed for allauth.
    'django.contrib.sites',

)

# List of locations of the template source files, in search order.
TEMPLATE_DIRS = ()

# List of callables that know how to import templates from various sources.
# See the comments in django/core/template/loader.py for interface
# documentation.
TEMPLATE_LOADERS = (
    'django.template.loaders.filesystem.Loader',
    'django.template.loaders.app_directories.Loader',
#     'django.template.loaders.eggs.Loader',
)

# List of processors used by RequestContext to populate the context.
# Each one should be a callable that takes the request object as its
# only parameter and returns a dictionary to add to the context.
TEMPLATE_CONTEXT_PROCESSORS = (
    'django.contrib.auth.context_processors.auth',
    'django.core.context_processors.debug',
    'django.core.context_processors.i18n',
    'django.core.context_processors.media',
    'django.core.context_processors.static',
    'django.core.context_processors.tz',
    'django.core.context_processors.request',
    'django.contrib.messages.context_processors.messages',

    # Allauth specific.
    "allauth.account.context_processors.account",
    "allauth.socialaccount.context_processors.socialaccount",
)

# Output to use in template system for invalid (e.g. misspelled) variables.
TEMPLATE_STRING_IF_INVALID = ''

# Default email address to use for various automated correspondence from
# the site managers.
#DEFAULT_FROM_EMAIL = 'no-reply@DOMAIN.com'

# Whether to append trailing slashes to URLs.
APPEND_SLASH = False

# Whether to prepend the "www." subdomain to URLs that don't have it.
PREPEND_WWW = False

# List of compiled regular expression objects representing URLs that need not
# be reported by BrokenLinkEmailsMiddleware. Here are a few examples:
#    import re
#    IGNORABLE_404_URLS = (
#        re.compile(r'^/apple-touch-icon.*\.png$'),
#        re.compile(r'^/favicon.ico$),
#        re.compile(r'^/robots.txt$),
#        re.compile(r'^/phpmyadmin/),
#        re.compile(r'\.(cgi|php|pl)$'),
#    )
IGNORABLE_404_URLS = ()

# SET IN local.py!!!
#
# A secret key for this particular Django installation. Used in secret-key
# hashing algorithms. See below in section "Environment specific".
#SECRET_KEY = ''

# Default module to use for urls.
ROOT_URLCONF = '{{ project_name }}.urls'

# Absolute filesystem path to the directory that will hold user-uploaded files.
# Example: "/var/www/example.com/media/"
MEDIA_ROOT = os.path.join(PUBLIC_DIR, 'media')

# URL that handles the media served from MEDIA_ROOT.
# Examples: "http://example.com/media/", "http://media.example.com/"
MEDIA_URL = '/media/'

# Absolute path to the directory static files should be collected to.
# Example: "/var/www/example.com/static/"
STATIC_ROOT = os.path.join(PUBLIC_DIR, 'static')

# URL that handles the static files served from STATIC_ROOT.
# Example: "http://example.com/static/", "http://static.example.com/"
STATIC_URL = '/static/'

# The Python dotted path to the WSGI application that Django's internal servers
# (runserver, runfcgi) will use. If `None`, the return value of
# 'django.core.wsgi.get_wsgi_application' is used, thus preserving the same
# behavior as previous versions of Django. Otherwise this should point to an
# actual WSGI application object.
WSGI_APPLICATION = '{{ project_name }}.wsgi.application'

##############
# MIDDLEWARE #
##############

# List of middleware classes to use.  Order is important; in the request phase,
# this middleware classes will be applied in the order given, and in the
# response phase the middleware will be applied in reverse order.
MIDDLEWARE_CLASSES = (
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
#     'django.middleware.http.ConditionalGetMiddleware',
#     'django.middleware.gzip.GZipMiddleware',
)

##################
# AUTHENTICATION #
##################

AUTHENTICATION_BACKENDS = (
    'django.contrib.auth.backends.ModelBackend',

    # `allauth` specific authentication methods, such as login by e-mail
    "allauth.account.auth_backends.AuthenticationBackend",
)

LOGIN_URL = '/accounts/login/'
LOGOUT_URL = '/accounts/logout/'
LOGIN_REDIRECT_URL = '/'

# The number of days a password reset link is valid for
PASSWORD_RESET_TIMEOUT_DAYS = 3

############
# FIXTURES #
############

# The list of directories to search for fixtures
FIXTURE_DIRS = (
    os.path.join(DATA_DIR, 'fixtures'),
)

###############
# STATICFILES #
###############

# A list of locations of additional static files
STATICFILES_DIRS = (
)

# List of finder classes that know how to find static files in
# various locations.
STATICFILES_FINDERS = (
    'django.contrib.staticfiles.finders.FileSystemFinder',
    'django.contrib.staticfiles.finders.AppDirectoriesFinder',
    'djangobower.finders.BowerFinder',
)

###########
# Logging #
###########

LOGGING = {
    'version': 1,
    'disable_existing_loggers': False,
    'formatters': {
    'verbose': {
            'format': '%(levelname)s %(asctime)s %(module)s %(process)d %(thread)d %(message)s'
        },
        'simple': {
            'format': '%(levelname)s %(message)s'
        },
    },
    'handlers': {
        'file_requests': {
            'level': 'INFO',
            'class': 'logging.FileHandler',
            'filename': os.path.join(DATA_DIR, 'logs', 'requests.log'),
        },
        'file_security': {
            'level': 'INFO',
            'class': 'logging.FileHandler',
            'filename': os.path.join(DATA_DIR, 'logs', 'security.log')
        }
    },
    'loggers': {
        'django.request': {
            'handlers': ['file_requests'],
            'level': 'INFO',
            'propagate': False,
        },
        'django.security': {
            'handlers': ['file_security'],
            'level': 'INFO',
            'propagate': False,
        },
    },
}


################
# APP SPECIFIC #
################

# Django Site framework settings.
SITE_ID = 1

# Crispy form helper settings.
CRISPY_TEMPLATE_PACK = 'bootstrap3'

# Bower settings.
BOWER_COMPONENTS_ROOT = DATA_DIR
BOWER_INSTALLED_APPS = (
    'jquery',
    'modernizr',

    # POLYFILLS: javascript fallback solutions for older browsers.

    # CSS3 selectors for IE 6-8.
    'selectivizr',
    # min/max width media queries for IE 6-8.
    'respond',
    # CSS3 styles for IE 6-8.
    'bower-pie',
    # HTML5 tag support for IE 6-8.
    'html5shiv',
)

# pipeline asset manager.

STATICFILES_STORAGE = 'pipeline.storage.PipelineCachedStorage'
PIPELINE_CSS_COMPRESSOR = 'pipeline.compressors.yui.YUICompressor'
PIPELINE_JS_COMPRESSOR = 'pipeline.compressors.yui.YUICompressor'

PIPELINE_CSS = {
    'screen': {
        'source_filenames': (
            'css/screen.css',
        ),
        'output_filename': 'css/base.css',
        'extra_content': (),
    },
    'ie': {
        'source_filenames': (
            'css/ie.css',
        ),
        'output_filename': 'css/ie.css',
        'extra_content': (),
    },
    'print': {
        'source_filenames': (
            'css/print.css',
        ),
        'output_filename': 'css/print.css',
        'extra_content': (),
    },
}

PIPELINE_JS = {
    'base': {
        'source_filenames': (
            'modernizr/modernizr.js',
            'jquery/dist/jquery.js',
            'js/bootstrap.js',
            'js/base.js',
        ),
        'output_filename': 'js/base.js',
    },
    'iepolyfills': {
        'source_filenames': (
            'html5shiv/dist/html5shiv.js ',
            'respond/dest/respond.src.js',
            'selectivizr/selectivizr.js',
        ),
        'output_filename': 'js/ie_poly.js'
    }
}


########################
# ENVIRONMENT SPECIFIC #
########################

# Many environment settings, like the database URL and the SECRET_KEY should
# be set with environment variables, and not in the code.
# Some things, like added enabled applications can be configured here though.
# The environment will be set by the ENV environment variable, and defaults
# to production.

SECRET_KEY = os.environ.get('SECRET_KEY')

DATABASES['default'] = {
    'ENGINE': os.environ.get('DB_ENGINE', 'django.db.backends.mysql'),
    'NAME': os.environ.get('DB_NAME')
}

# Default settings for development, so you can get started with coding right
# away.
if ENV == 'dev':
    # Set default sqlite database for development.
    DATABASES['default'] = {
        'ENGINE': 'django.db.backends.sqlite3',
        'NAME': os.path.join(DATA_DIR, 'db', 'db.sqlite3'),
    }

    # Default secret_key for dev.
    SECRET_KEY = '{{ secret_key }}'

    # To extend any settings from settings/base.py here's an example:
    INSTALLED_APPS = INSTALLED_APPS + ()

    DEBUG = TEMPLATE_DEBUG = True
    TEMPLATE_STRING_IF_INVALID = '<VAR_NONEXISTANT>'

    ALLOWED_HOSTS = ['*']

    # In development,  just print emails to console instead of sending them.
    EMAIL_BACKEND = 'django.core.mail.backends.console.EmailBackend'

    

    LOGGING['handlers'] = {
        'file': {
            'level': 'DEBUG',
            'class': 'logging.FileHandler',
            'filename': os.path.join(DATA_DIR, 'logs', 'debug.log'),
        },
        'console':{
            'level': 'DEBUG',
            'class': 'logging.StreamHandler',
            'formatter': 'simple'
        },
    }
    LOGGING['loggers'] = {
        'django': {
            'handlers': ['file', 'console'],
            'level': 'DEBUG',
            'propagate': True,
        },
    }




#!/usr/bin/env python
import os
import sys

if __name__ == "__main__":
    # Make it possible to run from any directory.
    os.chdir(os.path.dirname(os.path.realpath(__file__)))

    os.environ.setdefault("DJANGO_SETTINGS_MODULE", "{{ project_name }}.settings")

    sys.path.append('apps')
    sys.path.append('lib')

    # Now add virtualenv site-packages path.
    from {{ project_name }} import settings
    sys.path.append(os.path.join(settings.VIRTENV_DIR, settings.VIRTENV_PACKAGE_DIR))

    from django.core.management import execute_from_command_line

    execute_from_command_line(sys.argv)



import os
from setuptools import setup

README = open(os.path.join(os.path.dirname(__file__), 'README.md')).read()

# Allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

setup(
    name = 'django-kickstart',
    version = '0.1.4',
    packages = ['django_kickstart'],
    include_package_data = True,
    entry_points = {
        'console_scripts': [
            'django-kickstart = django_kickstart.cli:main'
        ]
    },
    install_requires = [
        'Django >= 1.6',
        'virtualenv',
    ],
    license = 'BSD License',
    description = 'Tool for kickstarting django projects.',
    long_description = README,
    url = 'https://github.com/theduke/django-kickstart',
    author = 'Christoph Herzog',
    author_email = 'chris@theduke.at',
    classifiers =[
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content'
    ]
)



from django.conf import settings
from django.conf.urls import patterns, include, url
from django.contrib.staticfiles.urls import staticfiles_urlpatterns
from django.contrib import admin

urlpatterns = patterns('',
    # Examples:
    # url(r'^$', '{{ project_name }}.views.home', name='home'),
    # url(r'^blog/', include('blog.urls')),

    url(r'^admin/', include(admin.site.urls)),

    # Allauth account urls.
    (r'^accounts/', include('allauth.urls')),

    url(r'^$', '{{ project_name }}.views.home', name='home'),
)

## In DEBUG mode, serve media files through Django.
if settings.DEBUG:
    urlpatterns += staticfiles_urlpatterns()
    # Remove leading and trailing slashes so the regex matches.
    media_url = settings.MEDIA_URL.lstrip('/').rstrip('/')
    urlpatterns += patterns('',
        (r'^%s/(?P<path>.*)$' % media_url, 'django.views.static.serve',
         {'document_root': settings.MEDIA_ROOT}),
    )



"""
WSGI config for {{ project_name }} project.

It exposes the WSGI callable as a module-level variable named ``application``.

For more information on this file, see
https://docs.djangoproject.com/en/{{ docs_version }}/howto/deployment/wsgi/
"""

import os
import sys

# Add apps and lib directories to the python path.
DIR = os.path.dirname(os.path.realpath(__file__))
sys.path.append(os.path.dirname(DIR))

from {{ project_name }} import settings
sys.path.append(settings.VIRTENV_DIR)
sys.path.append(os.path.join(settings.BASE_DIR, 'lib'))

os.environ.setdefault("DJANGO_SETTINGS_MODULE", "{{ project_name }}.settings")

from django.core.wsgi import get_wsgi_application
application = get_wsgi_application()
